#!/bin/bash

# Script to copy the relevant debian-edu documentation from the www
# section of the skolelinux/debian-edu cvs, and to put it into a
# sensible structure in the package.  Files will be updated only if
# the skolelinux/debian-edu cvs is available in the expected location

if [ -d ../../www ]; then
# cvs is available, run update and fetch new files
    pushd ../../www/ 2>&1 >/dev/null 
    cvs update
    popd 2>&1 >/dev/null
    SRCDIR="../../www"
    DOCDIR="documentation"

# Remove old files from previous runs
    rm -rf $DOCDIR
# Create directory again.
    mkdir $DOCDIR

# kurs - courses
    DESTDIR=$DOCDIR/kurs
    mkdir $DESTDIR
    mkdir $DESTDIR/figurer
    mkdir $DESTDIR/bilder

    cp -a $SRCDIR/kurs/kursdok.html $DESTDIR
    cp -a $SRCDIR/kurs/kursdok.pdf $DESTDIR
    cp -a $SRCDIR/kurs/bilder/autorisering.jpg $DESTDIR/bilder
    cp -a $SRCDIR/kurs/bilder/kommandoskall0.jpg $DESTDIR/bilder
    cp -a $SRCDIR/kurs/bilder/kontrollsenter0.jpg $DESTDIR/bilder
    cp -a $SRCDIR/kurs/bilder/kontrollsenter_skriver0.jpg $DESTDIR/bilder
    cp -a $SRCDIR/kurs/bilder/kontrollsenter_skriver1.jpg $DESTDIR/bilder
    cp -a $SRCDIR/kurs/bilder/kontrollsenter_skriver_leggtil0.jpg \
	$DESTDIR/bilder
    cp -a $SRCDIR/kurs/bilder/kontrollsenter_skriver_leggtil1.jpg \
	$DESTDIR/bilder
    cp -a $SRCDIR/kurs/bilder/kontrollsenter_skriver_leggtil2.jpg \
	$DESTDIR/bilder
    cp -a $SRCDIR/kurs/bilder/kontrollsenter_skriver_leggtil3.jpg \
	$DESTDIR/bilder
    cp -a $SRCDIR/kurs/bilder/kontrollsenter_skriver_stillinn0.jpg \
	$DESTDIR/bilder
    cp -a $SRCDIR/kurs/bilder/ldap_brukeradm_web_lt.jpg $DESTDIR/bilder
    cp -a $SRCDIR/kurs/bilder/skrivebord.jpg $DESTDIR/bilder
    cp -a $SRCDIR/kurs/bilder/tk_ulsrud.jpg $DESTDIR/bilder
    cp -a $SRCDIR/kurs/bilder/webmin_added.jpg $DESTDIR/bilder
    cp -a $SRCDIR/kurs/bilder/webmin_grohb.jpg $DESTDIR/bilder
    cp -a $SRCDIR/kurs/bilder/webmin_user.jpg $DESTDIR/bilder
    cp -a $SRCDIR/kurs/figurer/arkitektur0.jpg $DESTDIR/figurer
    cp -a $SRCDIR/kurs/figurer/arkitektur1_krkabel.jpg $DESTDIR/figurer
    cp -a $SRCDIR/kurs/figurer/arkitektur1_svitsj.jpg $DESTDIR/figurer
    cp -a $SRCDIR/kurs/figurer/kake.jpg $DESTDIR/figurer
    cp -a $SRCDIR/kurs/figurer/nettverksarkitektur.jpg $DESTDIR/figurer
    cp -a $SRCDIR/kurs/figurer/stykke1.jpg $DESTDIR/figurer
    cp -a $SRCDIR/kurs/figurer/stykke2.jpg $DESTDIR/figurer
    cp -a $SRCDIR/kurs/figurer/stykke3.jpg $DESTDIR/figurer
    cp -a $SRCDIR/kurs/figurer/stykke4.jpg $DESTDIR/figurer
    cp -a $SRCDIR/kurs/figurer/stykke5.jpg $DESTDIR/figurer

# drift - system administration
    DESTDIR=$DOCDIR/drift
    mkdir $DESTDIR
    mkdir $DESTDIR/images

    cp -a $SRCDIR/dokumentasjon/IKT-bok.html* $DESTDIR
    cp -a $SRCDIR/dokumentasjon/install.html $DESTDIR
    cp -a $SRCDIR/dokumentasjon/images/*png $DESTDIR/images

    cp -a $SRCDIR/dokumentasjon/driftbok/driftbok.sgml $DESTDIR
    cp -a $SRCDIR/dokumentasjon/driftbok/netgroups.sgml $DESTDIR
    cp -a $SRCDIR/dokumentasjon/driftbok/images/*png $DESTDIR/images

# arkitektur - architecture
    DESTDIR=$DOCDIR/arkitektur
    mkdir $DESTDIR

    cp -a $SRCDIR/arkitektur/arkitektur*pdf $DESTDIR
    cp -a $SRCDIR/arkitektur/network-arch*pdf $DESTDIR
    cp -a $SRCDIR/arkitektur/brannmur_virus.txt $DESTDIR

# innfring - introduction
#    DESTDIR=$DOCDIR/innforing
#    mkdir $DESTDIR

# erfaringsrapporter - experience reports
# Not included at this time because of lacking cvs presence:
# iitet
#   http://www.skolelinux.no/~ringe/SLX-iTet-rapport.pdf
# Hvordan bytte til Skolelinux, Time kommune
#   http://skolenettet.ls.no/imaker?id=140820&malgruppe=0&trinn=0&sub=0

    DESTDIR=$DOCDIR/erfaringer
    mkdir $DESTDIR

#   selsbak
#    cp -a $SRCDIR/rapporter/rapport_trondheim.pdf $DESTDIR
#   nittedal (sv_?.pdf)
#    cp -a $SRCDIR/rapporter/sv_eksamen_2004.pdf $DESTDIR
#   statskonsult
#    cp -a $SRCDIR/rapporter/statskonsult_2003_24.pdf $DESTDIR
#   teleplan
#    cp -a $SRCDIR/rapporter/teleplan_03112003.pdf $DESTDIR
#   IT-strategisk hefte fra Lringssenteret
#    cp -a $SRCDIR/rapporter/IKT_i_skolen.pdf $DESTDIR
#   Linux p Vardsen skole i Kristiansand
#    cp -a $SRCDIR/brev/vardaasen.html $DESTDIR
#   Eksamen med Linux p Hakadal ungdomsskole
#    cp -a $SRCDIR/brev/hakkadal.html $DESTDIR
#   Mac- og windows-integrasjon
    cp -a $SRCDIR/info/studentgrupper/2003-macwin-integr/rapport/rapport.pdf \
	$DESTDIR
else
    echo "CVS repository not available, files not updated"
fi

exit 0
